@@ -79,6 +79,11 @@ struct ProjectConfiguration
   bool            m_inheritconfig;
   bool            m_target_install;
   QString         m_target_install_path;
+
+  QMap<QString,QString> m_variables;
+  QStringList    m_removed_variables;
+  QStringList    m_projectInclude;
+
 };
 
 
@@ -146,6 +151,8 @@ public:
 
 
 
+
+
     ProjectConfiguration configuration;
 
     FileBuffer m_FileBuffer;
@@ -177,9 +184,9 @@ public:
   InsideCheckListItem(QListView *parent,QListViewItem *after,SubqmakeprojectItem *item, ProjectConfigurationDlg *config):
       QCheckListItem(parent,
 #if KDE_VERSION > 305
-		     after,
+             after,
 #endif
-		     item->relpath.right(item->relpath.length()-1),QCheckListItem::CheckBox)
+             item->relpath.right(item->relpath.length()-1),QCheckListItem::CheckBox)
   {
     prjItem=item;
     m_config = config;
@@ -196,9 +203,10 @@ protected:
 class GroupItem : public qProjectItem
 {
 public:
-    enum GroupType {NoType, Sources, Headers, Forms,Distfiles,Images,Lexsources,Yaccsources,Translations,IDLs, InstallRoot, InstallObject};
+    enum GroupType {NoType, Sources, Headers, Forms,Distfiles,Images,Lexsources,Yaccsources,Translations,IDLs, InstallRoot, InstallObject, MaxTypeEnum };
 
     static GroupType groupTypeForExtension(const QString &ext);
+    static void groupTypeMeanings(GroupItem::GroupType type, QString& title, QString& ext);
 
     GroupItem(QListView *lv, GroupType type, const QString &text,const QString &scopeString);
 
@@ -213,6 +221,9 @@ public:
     // end qmake INSTALLS support
     GroupType           groupType;
     SubqmakeprojectItem*     owner;
+
+protected:
+    void paintCell(QPainter* p, const QColorGroup& cg, int column, int width, int align);
 };
 
 
@@ -283,7 +294,7 @@ public:
 
     enum TrollProjectView { SubprojectView, DetailsView };
     void setLastFocusedView(TrollProjectView view);
-    
+
 public slots:
     void slotBuildTarget();
     void slotRebuildTarget();
@@ -304,7 +315,7 @@ public slots:
 
 protected:
     virtual void focusInEvent(QFocusEvent *e);
-    
+
 private slots:
     void slotOverviewSelectionChanged(QListViewItem *item);
     void slotOverviewContextMenu(KListView *, QListViewItem *item, const QPoint &p);
@@ -370,7 +381,7 @@ private:
     TrollProjectPart *m_part;
 
     TrollProjectView m_lastFocusedView;
-    
+
     friend class ChooseSubprojectDlg;
 };
 
