@@ -29,7 +29,7 @@ public:
 
 public slots:
 	void accept( );
-	void slotNewPCS();
+    void slotNewPCS();
 
 protected slots:
 	void slotGetterSetterValuesChanged();
@@ -38,7 +38,6 @@ protected slots:
 private slots:
 	void catalogRegistered( Catalog* c );
 	void catalogUnregistered( Catalog* c );
-	void slotToogleQtUsed();
 
 private:
 	void initGeneralTab();
@@ -52,6 +51,9 @@ private:
 
 	void initGetterSetterTab();
 	void saveGetterSetterTab();
+    
+    void initSplitTab();
+    void saveSplitTab();
 
 private:
 	CppSupportPart* m_pPart;
