@@ -2,6 +2,9 @@
 *   Copyright (C) 2003 by Roberto Raggi                                   *
 *   roberto@kdevelop.org                                                  *
 *                                                                         *
+*   Copyright (C) 2006 by Jens Dagerbo                                    *
+*   jens.dagerbo@swipnet.se                                               *
+*                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
@@ -40,9 +43,9 @@ SettingsDialog::SettingsDialog( QWidget* parent, const char* name, WFlags fl )
 	pCustomEditor = req->customEditor();
 	elb = new KEditListBox( i18n( "Directories to Parse" ), pCustomEditor, this );
 
-	grid->addMultiCellWidget( elb, 2, 2, 0, grid->numCols() );
+	grid->addMultiCellWidget( elb, 3, 3, 0, grid->numCols() );
 
-	connect( dbName_edit, SIGNAL( textChanged( const QString& ) ), this, SLOT( validate() ) );
+	//	connect( dbName_edit, SIGNAL( textChanged( const QString& ) ), this, SLOT( validate() ) );
 	connect( elb->addButton(), SIGNAL( clicked() ), this, SLOT( validate() ) );
 	connect( elb->removeButton(), SIGNAL( clicked() ), this, SLOT( validate() ) );
 	connect( elb, SIGNAL( added( const QString& ) ), this, SLOT( validateDirectory( const QString& ) ) );
@@ -53,7 +56,8 @@ SettingsDialog::~SettingsDialog()
 
 QString SettingsDialog::dbName( ) const
 {
-	return dbName_edit->text();
+	return QString();
+// 	return dbName_edit->text();
 }
 
 QStringList SettingsDialog::dirs( ) const
@@ -61,6 +65,11 @@ QStringList SettingsDialog::dirs( ) const
 	return elb->items();
 }
 
+QString SettingsDialog::filePattern( ) const
+{
+	return pattern_edit->text();
+}
+
 bool SettingsDialog::recursive( ) const
 {
 	return recursive_box->isChecked();
@@ -68,7 +77,8 @@ bool SettingsDialog::recursive( ) const
 
 void SettingsDialog::validate()
 {
-	emit enabled( !dbName_edit->text().isEmpty() && elb->listBox() ->count() > 0 );
+// 	emit enabled( !dbName_edit->text().isEmpty() && elb->listBox() ->count() > 0 );
+ 	emit enabled( elb->listBox()->count() > 0 );
 }
 
 void SettingsDialog::validateDirectory( const QString & dir )
@@ -93,3 +103,4 @@ void SettingsDialog::validateDirectory( const QString & dir )
 
 
 
+
