@@ -21,6 +21,7 @@
 
 #include <klistview.h>
 #include <qguardedptr.h>
+#include <qdatetime.h>
 
 class CppSupportPart;
 class QTimer;
@@ -52,6 +53,7 @@ public:
 
 	void removeAllProblems( const QString& filename );
 	void reportProblem( const QString& fileName, const Problem& p );
+	bool hasErrors(const QString& file);
 
 public slots:
 	void reparse();
@@ -68,6 +70,7 @@ private slots:
 	void slotTabSelected( int tabindex );
 	void slotFilter();
 	void closedFile( const KURL &fileName );
+	void slotParseCheck();
 
 private:
 	QString levelToString( int level ) const;
@@ -94,6 +97,8 @@ private:
 	QGuardedPtr<KTextEditor::Document> m_document;
 	KTextEditor::MarkInterface* m_markIface;
 	QTimer* m_timer;
+	QTimer* m_parseCheckTimeout;
+	QTime m_timeout;
 	QString m_fileName;
 	int m_active;
 	int m_delay;
