@@ -28,6 +28,7 @@ StoreWalker::StoreWalker( const QString& fileName, CodeModel* store )
 StoreWalker::~StoreWalker()
 {}
 
+
 void StoreWalker::parseTranslationUnit( TranslationUnitAST* ast )
 {
 	m_file = m_store->create<FileModel>();
@@ -46,7 +47,7 @@ void StoreWalker::parseTranslationUnit( TranslationUnitAST* ast )
 	m_anon = 0;
 	m_imports.clear();
 	
-	m_imports << QStringList();
+	m_imports << QPair<QMap<QString, ClassDom>, QStringList>(QMap<QString, ClassDom>(), QStringList());
 	TreeParser::parseTranslationUnit( ast );
 	m_imports.pop_back();
 }
@@ -109,7 +110,8 @@ void StoreWalker::parseUsing( UsingAST* ast )
 void StoreWalker::parseUsingDirective( UsingDirectiveAST* ast )
 {
 	QString name = ast->name()->unqualifiedName()->text();
-	m_imports.back().push_back( name );
+	QString tx = ast->name()->text();
+	m_imports.back().second.push_back( ast->name()->text() );
 }
 
 void StoreWalker::parseTypedef( TypedefAST* ast )
@@ -167,6 +169,7 @@ void StoreWalker::parseTypedef( TypedefAST* ast )
 			typeAlias->setFileName( m_fileName );
 			typeAlias->setName( id );
 			typeAlias->setType( type );
+			typeAlias->setComment( ast->comment() );
 			
 			int line, col;
 			initDecl->getStartPosition( &line, &col );
@@ -210,16 +213,22 @@ void StoreWalker::parseTypedef( TypedefAST* ast )
 
 void StoreWalker::parseTemplateDeclaration( TemplateDeclarationAST* ast )
 {
+	m_currentTemplateDeclarator.push( ast );
 	if ( ast->declaration() )
 		parseDeclaration( ast->declaration() );
 	
+	
+	
 	TreeParser::parseTemplateDeclaration( ast );
+	
+	m_currentTemplateDeclarator.pop();
 }
 
 void StoreWalker::parseSimpleDeclaration( SimpleDeclarationAST* ast )
 {
 	TypeSpecifierAST * typeSpec = ast->typeSpec();
 	InitDeclaratorListAST* declarators = ast->initDeclaratorList();
+	CommentPusher push( *this, ast->comment() );
 	
 	if ( typeSpec )
 		parseTypeSpecifier( typeSpec );
@@ -238,6 +247,20 @@ void StoreWalker::parseSimpleDeclaration( SimpleDeclarationAST* ast )
 	}
 }
 
+
+QStringList StoreWalker::findScope( const QStringList& scope ) {
+	ClassDom d = findClassFromScope( scope );
+	
+	if( d ) {
+		QStringList ret = d->scope();
+		ret << d->name();
+		return ret;
+	}
+	
+	return scope;
+}
+
+
 void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 {
 	TypeSpecifierAST * typeSpec = ast->typeSpec();
@@ -295,6 +318,11 @@ void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 	QString id = d->declaratorId() ->unqualifiedName() ->text().stripWhiteSpace();
 	
 	QStringList scope = scopeOfDeclarator( d, m_currentScope );
+	ClassDom c = findClassFromScope( scope );
+	if( c ){
+		scope = c->scope();
+		scope << c->name();
+	}
 	
 	FunctionDefinitionDom method = m_store->create<FunctionDefinitionModel>();
 	method->setScope( scope );
@@ -309,6 +337,10 @@ void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 	method->setFileName( m_fileName );
 	method->setStartPosition( startLine, startColumn );
 	method->setEndPosition( endLine, endColumn );
+	if( !ast->comment().isEmpty() )
+		method->setComment( ast->comment() );
+	
+	checkTemplateDeclarator( & (*method) );
 	
 	if ( m_inSignals )
 		method->setSignal( true );
@@ -316,7 +348,9 @@ void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 	if ( m_inSlots )
 		method->setSlot( true );
 	
-	if ( m_currentClass.top() || ( method->name() == "main" && scope.isEmpty() ) )
+	if( c && c->isClass() )
+		method->setConstant( d->constant() != 0 );
+	else if ( m_currentClass.top() || ( method->name() == "main" && scope.isEmpty() ) )
 	{
 		method->setConstant( d->constant() != 0 );
 		method->setAccess( m_currentAccess );
@@ -347,6 +381,41 @@ void StoreWalker::parseTypeSpecifier( TypeSpecifierAST* ast )
 	TreeParser::parseTypeSpecifier( ast );
 }
 
+void StoreWalker::takeTemplateParams( TemplateModelItem& target, TemplateDeclarationAST* ast) {
+	TemplateParameterListAST* pl = ast->templateParameterList();
+	if( pl ) {
+		QPtrList<TemplateParameterAST> list = pl->templateParameterList();
+		
+		TemplateParameterAST* curr = list.first();
+		while( curr != 0 ) {
+			QString a, b;
+			if( curr->typeParameter() && curr->typeParameter()->name() ) {
+				a = curr->typeParameter()->name()->text();
+				if( curr->typeParameter()->typeId() ) 
+					b =  curr->typeParameter()->typeId()->text();
+			}
+			
+			target.addTemplateParam( a, b );
+			CodeModelItem* cmi = dynamic_cast<CodeModelItem*>(&target);
+			QString nm = "0";
+			if(cmi) nm = cmi->name();
+		kdDebug() << "item " << nm << " taking template-parameters " << a << ", default=" << b << "\n";
+			curr = list.next();
+		}
+	}
+}
+
+void StoreWalker::checkTemplateDeclarator( TemplateModelItem* item ) {
+	if( !m_currentTemplateDeclarator.empty() && m_currentTemplateDeclarator.top() != 0) {
+		TemplateDeclarationAST* a = m_currentTemplateDeclarator.top();
+		
+		m_currentTemplateDeclarator.pop();
+		m_currentTemplateDeclarator.push(0);
+		
+		takeTemplateParams( *item, a );
+	}
+}
+
 void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 {
 	int startLine, startColumn;
@@ -382,20 +451,45 @@ void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 		className = ast->name() ->unqualifiedName() ->text().stripWhiteSpace();
 	}
 	
-	if ( !scopeOfName( ast->name(), QStringList() ).isEmpty() )
-	{
-		kdDebug( 9007 ) << "skip private class declarations" << endl;
-		return ;
-	}
-	
 	ClassDom klass = m_store->create<ClassModel>();
 	klass->setStartPosition( startLine, startColumn );
 	klass->setEndPosition( endLine, endColumn );
 	klass->setFileName( m_fileName );
-	
 	klass->setName( className );
+	klass->setComment( ast->comment() );
 	
-	klass->setScope( m_currentScope );
+	checkTemplateDeclarator( &(*klass) );
+	
+	bool embed = !scopeOfName( ast->name(), QStringList() ).isEmpty();
+	
+	QStringList oldScope;
+	
+	
+	if( embed ) {
+		ClassDom embedderClass = findClassFromScope( m_currentScope + scopeOfName( ast->name(), QStringList() ));
+		
+		if(embedderClass) {
+			if(embedderClass->fileName() != klass->fileName()) {
+				///since we are creating a link between both files, put them into the same parsing-group
+				FileDom dm = embedderClass->file();
+				if( dm ) {
+					m_file->setGroupId( m_store->mergeGroups( dm->groupId(), m_file->groupId() ) );
+				}else{
+					kdDebug() << "file " << embedderClass->fileName() << " missing in store \n";
+				}
+			}
+				
+			oldScope = m_currentScope;
+			m_currentScope = embedderClass->scope();
+			m_currentScope.push_back( embedderClass->name() );
+			m_currentClass.push( embedderClass );
+			
+			//m_file->addClass( klass );//experiment
+		}else{
+			kdDebug( 9007 ) << "could not find embedding class " << QStringList(m_currentScope + scopeOfName( ast->name(), QStringList() )).join("::") << " for " << className << endl;
+			embed = false;
+		}
+	}
 	
 	if ( m_currentClass.top() )
 		m_currentClass.top() ->addClass( klass );
@@ -404,21 +498,30 @@ void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 	else
 		m_file->addClass( klass );
 	
+	klass->setScope( m_currentScope );
+	
+	
 	if ( ast->baseClause() )
 		parseBaseClause( ast->baseClause(), klass );
 	
 	m_currentScope.push_back( className );
 	m_currentClass.push( klass );
 	
-	m_imports.push_back( QStringList() );
+	//m_imports.push_back( QStringList() );
 	
 	TreeParser::parseClassSpecifier( ast );
 	
-	m_imports.pop_back();
+
+	//m_imports.pop_back();
 	m_currentClass.pop();
 	
 	m_currentScope.pop_back();
 	
+	if( embed ) {
+		m_currentScope = oldScope;
+		m_currentClass.pop();
+	}
+	
 	m_currentAccess = oldAccess;
 	m_inSlots = oldInSlots;
 	m_inSignals = oldInSignals;
@@ -426,6 +529,31 @@ void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 
 void StoreWalker::parseEnumSpecifier( EnumSpecifierAST* ast )
 {
+	if( ast->name() ) {
+	TypeAliasDom typeAlias = m_store->create<TypeAliasModel>();
+	typeAlias->setFileName( m_fileName );
+	typeAlias->setName( ast->name()->text() );
+	typeAlias->setType( "int" );
+	typeAlias->setComment( ast->comment() );
+	
+	int line, col;
+	ast->getStartPosition( &line, &col );
+	typeAlias->setStartPosition( line, col );
+	
+	ast->getEndPosition( &line, &col );
+	typeAlias->setEndPosition( line, col );
+	
+	if ( m_currentClass.top() )
+		m_currentClass.top() ->addTypeAlias( typeAlias );
+	else if ( m_currentNamespace.top() )
+		m_currentNamespace.top() ->addTypeAlias( typeAlias );
+	else
+		m_file->addTypeAlias( typeAlias );
+	} else {
+		kdDebug() << "enum has no name" << endl;
+	}
+	
+	
 	QPtrList<EnumeratorAST> l = ast->enumeratorList();
 	QPtrListIterator<EnumeratorAST> it( l );
 	while ( it.current() )
@@ -435,6 +563,7 @@ void StoreWalker::parseEnumSpecifier( EnumSpecifierAST* ast )
 		attr->setFileName( m_fileName );
 		attr->setAccess( m_currentAccess );
 		attr->setType( "int" );
+		attr->setComment( (*it)->comment() );
 		attr->setStatic( true );
 		
 		int startLine, startColumn;
@@ -490,13 +619,15 @@ void StoreWalker::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
 	
 	if ( !scopeOfDeclarator( d, QStringList() ).isEmpty() )
 	{
-		kdDebug( 9007 ) << "skip declaration" << endl;
+		kdDebug( 9007 ) << "skip declaration of " << QStringList(scopeOfDeclarator( d, QStringList() )).join("::") << "::" << id << endl;
 		return ;
 	}
 	
 	VariableDom attr = m_store->create<VariableModel>();
 	attr->setName( id );
 	attr->setFileName( m_fileName );
+	attr->setComment( comment() );
+	
 	
 	if ( m_currentClass.top() )
 		m_currentClass.top() ->addVariable( attr );
@@ -641,6 +772,7 @@ void StoreWalker::parseFunctionDeclaration( GroupAST* funSpec, GroupAST* storage
 	FunctionDom method = m_store->create<FunctionModel>();
 	method->setName( id );
 	
+	method->setComment( comment() );
 	method->setFileName( m_fileName );
 	method->setStartPosition( startLine, startColumn );
 	method->setEndPosition( endLine, endColumn );
@@ -650,6 +782,9 @@ void StoreWalker::parseFunctionDeclaration( GroupAST* funSpec, GroupAST* storage
 	method->setAbstract( isPure );
 	parseFunctionArguments( d, method );
 	
+	checkTemplateDeclarator( & (*method) );
+		
+	
 	if ( m_inSignals )
 		method->setSignal( true );
 	
@@ -761,6 +896,69 @@ QStringList StoreWalker::scopeOfName( NameAST* id, const QStringList& startScope
 	return scope;
 }
 
+
+ClassDom StoreWalker::findClassFromScope( const QStringList& scope ) 
+{
+	QString scopeText = scope.join("::");
+	if( !m_imports.isEmpty() ) {
+		QMapIterator<QString, ClassDom> it = m_imports.back().first.find( scopeText );
+		if( it != m_imports.back().first.end() ) {
+			return *it;
+		}
+	}
+	
+	ClassDom c = classFromScope( scope );
+	if( c ) {
+		if( !m_imports.isEmpty() ) m_imports.back().first[ scopeText ] = c;
+		return c;
+	}
+	
+	if(!m_imports.isEmpty() && !m_imports.back().second.isEmpty()) {
+			///try the same using one of the imports(performance-wise this is not good, but simple)
+		
+		QStringList::iterator it = m_imports.back().second.begin();
+		while(it != m_imports.back().second.end()) {
+			QStringList scp = QStringList::split("::", *it) + m_currentScope + scope;
+			c = classFromScope( scp );
+			if( c ) {
+				if( !m_imports.isEmpty() ) m_imports.back().first[ scopeText ] = c;
+				return c;
+			}
+			++it;
+		}
+	}
+	return c;
+}
+
+ClassDom StoreWalker::classFromScope(const QStringList& scope) {
+	if(scope.isEmpty())return ClassDom(0);
+	
+	NamespaceDom glob = m_store->globalNamespace();
+	if( !glob ) return ClassDom();
+	
+	ClassModel* curr =  glob ;
+	
+	QStringList::const_iterator mit = scope.begin();
+	
+	while(curr->isNamespace() && mit != scope.end() && ((NamespaceModel*)curr)->hasNamespace( *mit )) {
+		curr = &(*( ((NamespaceModel*)curr)->namespaceByName( *mit ) ));
+		++mit;
+	}
+	
+	while((curr->isNamespace() || curr->isClass()) && mit != scope.end() && curr->hasClass( *mit )) {
+		ClassList cl = curr->classByName( *mit );
+		curr = &(**cl.begin() );
+		++mit;
+	}
+	
+	if(mit == scope.end()) {
+		return curr;
+	}
+	
+	return ClassDom(0);
+}
+
+
 QStringList StoreWalker::scopeOfDeclarator( DeclaratorAST* d, const QStringList& startScope )
 {
 	return scopeOfName( d->declaratorId(), startScope );
