@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
 
@@ -51,7 +51,7 @@ enum Errors
    ErrorNoSuchFunction = 2,
    Warning = 3,
    Todo = 4,
-   Fixme = 5
+   Fixme = 5,
 };
 
 class PHPErrorView: public QWidget {
