@@ -108,7 +108,7 @@ struct LexerData
 Lexer::Lexer( Driver* driver )
     : d( new LexerData),
       m_driver( driver ),
-      m_recordComments( false ),
+      m_recordComments( true ),
       m_recordWhiteSpaces( false ),
       m_skipWordsEnabled( true ),
       m_preprocessorEnabled( true ),
@@ -232,7 +232,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
         int ppe = preprocessorEnabled();
 	setPreprocessorEnabled( false );
 	while( currentChar() && currentChar() != '\n' ){
-            Token tok;
+            Token tok(m_source);
             nextToken( tok, true );
         }
         m_startLine = true;
@@ -358,7 +358,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 
                 readWhiteSpaces();
 
-                Token tok;
+                Token tok(m_source);
                 nextToken( tok );
 
                 bool stringify = !m_inPreproc && tok == '#';
@@ -480,7 +480,7 @@ void Lexer::tokenize()
     m_size = 0;
 
     for( ;; ) {
-	Token tk;
+	Token tk(m_source);
 	nextToken( tk );
 
         if( tk.type() != -1 )
@@ -514,7 +514,7 @@ void Lexer::skip( int l, int r )
     int count = 0;
 
     while( !eof() ){
-	Token tk;
+	Token tk(m_source);
 	nextToken( tk );
 
 	if( (int)tk == l )
@@ -545,7 +545,7 @@ QString Lexer::readArgument()
 	if( ch.isNull() || (!count && (ch == ',' || ch == ')')) )
 	    break;
 
-	Token tk;
+	Token tk(m_source);
 	nextToken( tk );
 
 	if( tk == '(' ){
@@ -600,7 +600,7 @@ void Lexer::handleDirective( const QString& directive )
 
     // skip line
     while( currentChar() && currentChar() != '\n' ){
-        Token tk;
+        Token tk(m_source);
         nextToken( tk, true );
     }
 
@@ -680,7 +680,7 @@ void Lexer::processDefine( Macro& m )
 	    body += " ";
 	} else {
 
-	    Token tk;
+	    Token tk(m_source);
 	    nextToken( tk, true );
 
 	    if( tk.type() != -1 ){
@@ -834,7 +834,7 @@ int Lexer::macroPrimary()
 
     default:
 	{
-	    Token tk;
+	    Token tk(m_source);
 	    nextToken( tk, false );
 	    switch( tk.type() ){
 	    case Token_identifier:
