@@ -20,15 +20,254 @@
 #include "codemodel.h"
 #include <kdebug.h>
 
+
 CodeModel::CodeModel()
 {
     wipeout();
+    m_currentGroupId = 1;   ///0 stands for invalid group
 }
 
 CodeModel::~ CodeModel( )
 {
 }
 
+
+int CodeModel::newGroupId() {
+    return (m_currentGroupId++) * 2;
+}
+
+inline bool isSingleGroup( const int group ) {
+    return (group % 2) == 0;
+}
+
+QStringList CodeModel::getGroupStrings(int gid) const {
+    QStringList ret;
+    for(QMap<QString, FileDom>::ConstIterator it = m_files.begin(); it != m_files.end(); ++it) {
+        if((*it)->groupId() == gid) ret.append( (*it)-> name() );
+    }
+    return ret;
+}
+
+
+FileList CodeModel::getGroup(int gid) const {
+    FileList ret;
+    for(QMap<QString, FileDom>::ConstIterator it = m_files.begin(); it != m_files.end(); ++it) {
+        if((*it)->groupId() == gid) ret.append(*it);
+    }
+    return ret;
+}
+
+FileList CodeModel::getGroup( const FileDom& dom) const {
+    return getGroup( dom->groupId() );
+}
+
+int CodeModel::mergeGroups( int g1, int g2) {
+    if( !g1 || !g2 ) return 0;
+    if( g1 == g2 ) return g1;
+    int ng = isSingleGroup( g1 ) ? g2 : g1;
+    if( isSingleGroup( ng ) )
+        ng = newGroupId() + 1;
+    
+    for( QMap<QString, FileDom>::iterator it = m_files.begin(); it != m_files.end(); ++it ) {
+        if( (*it)->groupId() == g2 || (*it)->groupId() == g1 ) (*it)->setGroupId( ng );
+    }
+    return ng;
+}
+
+template<class Type> static void dumpMap( std::ostream& file, QMap<QString, Type>& map ) {
+    typename QMap<QString, Type>::Iterator it = map.begin();
+    for( ; it != map.end(); ++it) {
+        typename Type::Iterator it2 = (*it).begin();
+        for( ; it2 != (*it).end(); ++it2) {
+            (*it2) -> dump( file, true );
+        }
+    }
+}
+
+template<class Type> static void dumpMapDirect( std::ostream& file, QMap<QString, Type>& map ) {
+    typename QMap<QString, Type>::Iterator it = map.begin();
+    for( ; it != map.end(); ++it) {
+        (*it) -> dump( file, true );
+    }
+}
+
+void CodeModelItem::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+    
+    str << "name: " << name().ascii() << "\n";
+    str << "kind: " << m_kind << "  ";
+    
+    if( isFile() ) str << "isFile ";
+    if( isNamespace() ) str << "isNamespace ";
+    if( isClass() ) str << "isClass ";
+    if( isFunction() ) str << "isFunction ";
+    if( isFunctionDefinition() ) str << "isFunctionDefinition ";
+    if( isVariable() ) str << "isVariable ";
+    if( isArgument() ) str << "isArgument ";
+    if( isEnum() ) str << "isEnum ";
+    if( isEnumerator() ) str << "isEnumerator ";
+    if( isTypeAlias() ) str << "isTypeAlias ";
+    if( isCustom() ) str << "isCustom ";
+    str << "\n";
+    str << "File: " << fileName().ascii() << " ";
+    int line, col;
+    getStartPosition( &line, &col );
+    str << "s:(" << line << ", " << col << ") ";
+    getEndPosition( &line, &col );
+    str << "e:(" << line << ", " << col << ")\n";
+    
+    
+    Info.prepend( str.str().c_str() );
+    
+    file << Info.ascii() << "\n";
+    if(recurse) {} ///just to get rid of the warning
+}
+
+void ClassModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+    
+    
+    str << "scope: " << m_scope.join("::").ascii() << "\n";
+    str << "bases: " << m_baseClassList.join(" ").ascii() << "\n";
+    
+    Info.prepend( str.str().c_str() );
+    
+    CodeModelItem::dump( file, false, Info );
+    
+    if( recurse ) {
+        dumpMap( file, m_classes );
+    }
+}
+
+void NamespaceModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    Info.prepend( str.str().c_str() );
+
+    ClassModel::dump( file, false, Info );
+
+    if( recurse ) {
+        dumpMapDirect( file, m_namespaces );
+    }
+}    
+
+void ArgumentModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    str << "type: " << m_type.ascii() << " default: " << m_defaultValue.ascii() << "\n";
+    
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+    
+    if(recurse) {} ///just to get rid of the warning
+}
+
+void FunctionModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    str << "access: " << m_access;
+        
+    str << " scope: " << m_scope.join("::").ascii() << "\n";
+        
+    if(isAbstract()) str << "isAbstract ";
+    if(isConstant()) str << "isConstant ";
+    if(isFunction()) str << "isFunction ";
+    if(isInline()) str << "isInline ";
+    if(isSignal()) str << "isSignal ";
+    if(isSlot()) str << "isSlot ";
+    if(isStatic()) str << "isStatic ";
+    if(isVirtual()) str << "isVirtual ";
+        
+    str << "\n";
+    str << "result-type: " << resultType().ascii() << "\n";
+        
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+
+    if(recurse) {
+        for( ArgumentList::iterator it = m_arguments.begin(); it != m_arguments.end(); ++it) {
+            (*it) -> dump( file, true );
+        }
+    }
+}
+
+void VariableModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    str << "access: " << m_access << "type: " << m_type.ascii() << "\n";
+    
+    if(isStatic()) str << "isStatic ";
+
+    str << "\n";
+
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+    
+    if(recurse) {} ///just to get rid of the warning
+}
+
+void CodeModel::dump( std::ostream& file, QString Info ) {
+    ostringstream str(ostringstream::out);
+            
+    Info.prepend( str.str().c_str() );
+    
+    file << Info.ascii() << "\n";
+    
+    QMap<QString, FileDom>::iterator it = m_files.begin();
+    for(; it != m_files.end(); ++it) {
+        (*it) -> dump( file, true );
+    }
+}
+
+void EnumModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    str << "access: " << m_access << "\n";
+    
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+    
+    if( recurse ) {
+        dumpMapDirect( file, m_enumerators );
+    }
+}
+
+void EnumeratorModel::dump( std::ostream& file, bool recurse, QString Info ) 
+{
+    ostringstream str( ostringstream::out );
+
+    str << "value: " << m_value.ascii() << "\n";
+    
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+    
+    if(recurse) {} ///just to get rid of the warning
+}
+
+void TypeAliasModel::dump( std::ostream& file, bool recurse, QString Info ) {
+    ostringstream str( ostringstream::out );
+
+    str << "type: " << m_type.ascii() << "\n";
+    
+    Info.prepend( str.str().c_str() );
+
+    CodeModelItem::dump( file, false, Info );
+    
+    if(recurse) {} ///just to get rid of the warning
+}
+
 void CodeModel::wipeout()
 {
     m_files.clear();
@@ -38,33 +277,14 @@ void CodeModel::wipeout()
     m_globalNamespace = ns;
 }
 
-#if QT_VERSION < 0x030005
-template<class Key, class T>
-QValueList<T> QMap_values (QMap<Key, T> tcQMap) {
-    QValueList<T> values;
-    QMap<Key, T>::Iterator it;
-    for (it=tcQMap.begin(); it!=tcQMap.end(); ++it)
-      { values.append(*it); }
-    return values;
-}
-#endif
-
 FileList CodeModel::fileList( )
 {
-#if QT_VERSION >= 0x030005
     return m_files.values();
-#else
-    return QMap_values<QString, FileDom>(m_files);
-#endif
 }
 
 const FileList CodeModel::fileList( ) const
 {
-#if QT_VERSION >= 0x030005
     return m_files.values();
-#else
-    return QMap_values<QString, FileDom>(m_files);
-#endif
 }
 
 bool CodeModel::hasFile( const QString & name ) const
@@ -165,7 +385,13 @@ void CodeModel::removeNamespace( NamespaceDom target, NamespaceDom source )
 bool CodeModel::addFile( FileDom file )
 {
     if( file->name().isEmpty() )
-	return false;
+		return false;
+
+		if( m_files.find( file->name() ) != m_files.end() ) {
+			///the error-channel is set to 9007 because this problem appears with the cpp-support, so it is needed while debugging it
+			kdDebug(9007) << "file " << file->name() << " was added to code-model without removing it before! \n" << kdBacktrace() << endl;
+			removeFile( fileByName( file->name() ) );
+		}
 
     // update global namespace
     NamespaceList namespaceList = file->namespaceList();
@@ -302,20 +528,12 @@ NamespaceModel::NamespaceModel( CodeModel* model )
 
 NamespaceList NamespaceModel::namespaceList( )
 {
-#if QT_VERSION >= 0x030005
     return m_namespaces.values();
-#else
-    return QMap_values<QString, NamespaceDom> (m_namespaces);
-#endif
 }
 
 const NamespaceList NamespaceModel::namespaceList( ) const
 {
-#if QT_VERSION >= 0x030005
     return m_namespaces.values();
-#else
-    return QMap_values<QString, NamespaceDom> (m_namespaces);
-#endif
 }
 
 NamespaceDom NamespaceModel::namespaceByName( const QString & name )
@@ -349,7 +567,7 @@ void NamespaceModel::removeNamespace( NamespaceDom ns )
 
 // ------------------------------------------------------------------------
 FileModel::FileModel( CodeModel* model )
-    : NamespaceModel( model)
+    : NamespaceModel( model ), m_groupId( model->newGroupId() )
 {
 }
 
@@ -545,20 +763,12 @@ void ClassModel::removeFunctionDefinition( FunctionDefinitionDom fun )
 
 VariableList ClassModel::variableList( )
 {
-#if QT_VERSION >= 0x030005
     return m_variables.values();
-#else
-    return QMap_values<QString, VariableDom> (m_variables);
-#endif
 }
 
 const VariableList ClassModel::variableList( ) const
 {
-#if QT_VERSION >= 0x030005
     return m_variables.values();
-#else
-    return QMap_values<QString, VariableDom> (m_variables);
-#endif
 }
 
 VariableDom ClassModel::variableByName( const QString & name )
@@ -592,20 +802,12 @@ void ClassModel::removeVariable( VariableDom var )
 
 EnumList ClassModel::enumList( )
 {
-#if QT_VERSION >= 0x030005
     return m_enumerators.values();
-#else
-    return QMap_values<QString, EnumDom> (m_enumerators);
-#endif
 }
 
 const EnumList ClassModel::enumList( ) const
 {
-#if QT_VERSION >= 0x030005
     return m_enumerators.values();
-#else
-    return QMap_values<QString, EnumDom> (m_enumerators);
-#endif
 }
 
 EnumDom ClassModel::enumByName( const QString & name )
@@ -903,7 +1105,14 @@ void CodeModelItem::read( QDataStream & stream )
 	>> m_startLine
 	>> m_startColumn
 	>> m_endLine
-	>> m_endColumn;
+	>> m_endColumn
+        >> m_comment;
+    
+    if( isTemplateable() ) {
+        TemplateModelItem* t = (TemplateModelItem*)( this );
+        
+        t->read( stream );
+    }
 }
 
 void CodeModelItem::write( QDataStream & stream ) const
@@ -915,13 +1124,21 @@ void CodeModelItem::write( QDataStream & stream ) const
 	<< m_startLine
 	<< m_startColumn
 	<< m_endLine
-	<< m_endColumn;
+	<< m_endColumn
+        << m_comment;
+    
+    if( isTemplateable() ) {
+        TemplateModelItem* t = (TemplateModelItem*)( this );
+        t-> write( stream );
+    }
 }
 
 void ClassModel::read( QDataStream & stream )
 {
     CodeModelItem::read( stream );
 
+		TemplateModelItem::read( stream );
+		
     stream >> m_scope >> m_baseClassList;
 
     int n;
@@ -979,6 +1196,8 @@ void ClassModel::write( QDataStream & stream ) const
 {
     CodeModelItem::write( stream );
 
+		TemplateModelItem::write( stream );
+		
     stream << m_scope << m_baseClassList;
 
     const ClassList class_list = classList();
@@ -1040,11 +1259,13 @@ void NamespaceModel::write( QDataStream & stream ) const
 
 void FileModel::read( QDataStream & stream )
 {
+    stream >> m_groupId;
     NamespaceModel::read( stream );
 }
 
 void FileModel::write( QDataStream & stream ) const
 {
+    stream << m_groupId;
     NamespaceModel::write( stream );
 }
 
@@ -1065,6 +1286,7 @@ void ArgumentModel::write( QDataStream & stream ) const
 void FunctionModel::read( QDataStream & stream )
 {
     CodeModelItem::read( stream );
+		TemplateModelItem::read( stream );
 
     stream >> m_scope;
     stream >> d.flags;
@@ -1086,6 +1308,7 @@ void FunctionModel::read( QDataStream & stream )
 void FunctionModel::write( QDataStream & stream ) const
 {
     CodeModelItem::write( stream );
+		TemplateModelItem::write( stream );
 
     stream << m_scope;
     stream << d.flags;
@@ -1151,20 +1374,12 @@ void EnumModel::setAccess( int access )
 
 EnumeratorList EnumModel::enumeratorList( )
 {
-#if QT_VERSION >= 0x030005
     return m_enumerators.values();
-#else
-    return QMap_values<QString, EnumeratorDom> (m_enumerators);
-#endif
 }
 
 const EnumeratorList EnumModel::enumeratorList( ) const
 {
-#if QT_VERSION >= 0x030005
     return m_enumerators.values();
-#else
-    return QMap_values<QString, EnumeratorDom> (m_enumerators);
-#endif
 }
 
 void EnumModel::addEnumerator( EnumeratorDom enumerator )
@@ -1259,3 +1474,12 @@ void TypeAliasModel::setType( const QString & type )
     m_type = type;
 }
 
+FileList FileModel::wholeGroup() {
+    if( isSingleGroup( m_groupId ) ) return ( FileList() << FileDom(this) );
+    return codeModel()->getGroup( m_groupId );
+}
+
+QStringList FileModel::wholeGroupStrings() const {
+    if( isSingleGroup( m_groupId ) ) return (QStringList() << name() );
+    return codeModel()->getGroupStrings( m_groupId );
+}
