@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2004 Alexander Dymo <cloudtemple@mksat.net>
+   Copyright (C) 2004 Alexander Dymo <adymo@kdevelop.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,14 +17,24 @@
    Boston, MA 02111-1307, USA.
 */
 #include "kdevdesignerintegration.h"
+#include "kdevdesignerintegrationiface.h"
+
+class KDevDesignerIntegration::KDevDesignerIntegrationPrivate {
+public:
+  	KDevDesignerIntegrationIface *m_iface;
+};
 
 KDevDesignerIntegration::KDevDesignerIntegration(QObject *parent, const char *name)
  : QObject(parent, name)
 {
+  dptr = new KDevDesignerIntegrationPrivate();
+  
+  dptr->m_iface = new KDevDesignerIntegrationIface(this);
 }
 
 KDevDesignerIntegration::~KDevDesignerIntegration()
 {
+  delete dptr;
 }
 
 #include "kdevdesignerintegration.moc"
