@@ -1,3 +1,22 @@
+/***************************************************************************
+ *   Copyright (C) 2004 by ian reinhart geiser                             *
+ *   geiseri@kde.org                                                       *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ ***************************************************************************/
 #ifndef __DISTPART_WIDGET_H__
 #define __DISTPART_WIDGET_H__
 
@@ -5,11 +24,11 @@
 #include <qwidget.h>
 #include <qstring.h>
 #include "distpart_ui.h"
-#include <qlistbox.h>
+#include <klistbox.h>
 #include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qmultilineedit.h>
+#include <kpushbutton.h>
+#include <klineedit.h>
+#include <ktextedit.h>
 #include <qcombobox.h>
 #include <qprogressbar.h>
 
@@ -18,6 +37,7 @@ class DistpartPart;
 class QUrlOperator;
 class KProcess;
 class QTabWidget;
+class SpecSupport;
 
 namespace KParts {
 class ReadOnlyPart;
@@ -29,10 +49,8 @@ class DistpartDialog : public distpart_ui {
 
 public:
 
-    DistpartDialog(DistpartPart *part);
+    DistpartDialog(DistpartPart *part, QWidget *parent);
     ~DistpartDialog();
-
-    QTabWidget * plug_box;
     
 signals:
     void okay();
@@ -87,6 +105,11 @@ public slots:
     //  QCheckBox* uploadCustomCheckBox;
     void slotuploadCustomCheckBoxChanged();
 
+    void slotbuildAllPushButtonPressed();
+    void slotexportSPECPushButtonPressed();
+    void slotimportSPECPushButtonPressed();
+    void slotsrcPackagePushButtonPressed();
+
 public:
     bool getcustomProjectCheckBoxState();
     void setcustomProjectCheckBoxState(bool state);
@@ -173,8 +196,11 @@ public:
 private:
     void loadSettings();
     void storeSettings();
+    void setPackageData();
+    void getPackageData();
 
-    DistpartPart * m_part;
+    SpecSupport *m_spec;
+    DistpartPart *m_part;
     QString dir;
 };
 
