@@ -45,6 +45,7 @@ const char *template_desc[] = {
     "->MEMBER(",
     "class::MEMBER(",
     "OBJECT->member(",
+    "[OBJECT method",
     0
 };
 
@@ -52,16 +53,18 @@ const char *template_str[] = {
     "%s",
     "\\<%s\\>[\\t ]*=[^=]",
     "\\->[\\t ]*\\<%s\\>[\\t ]*\\(",
-    "[a-z0-9_$]+[\\t ]*::[\\t ]*\\<%s\\>[\\t ]*\\(",
-    "\\<%s\\>[\\t ]*\\->[\\t ]*[a-z0-9_$]+[\\t ]*\\(",
+    "[a-z0-9_$]\\+[\\t ]*::[\\t ]*\\<%s\\>[\\t ]*\\(",
+    "\\<%s\\>[\\t ]*\\->[\\t ]*[a-z0-9_$]\\+[\\t ]*\\(",
+    "\\[[\\t ]*\\<%s\\>[\\t ]*[a-zA-Z0-9_$:]",
     0
 };
 
 const char *filepatterns[] = {
-    "*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.cpp,*.cc,*.C,*.c++,*.cxx,*.inl,*.idl,*.c,*.m,*.mm,*.M",
-    "*.cpp,*.cc,*.C,*.c++,*.cxx,*.inl,*.c,*.m,*.mm,*.M",
+    "*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.idl,*.c,*.m,*.mm,*.M",
+    "*.cpp,*.cc,*.C,*.c++,*.cxx,*.ocl,*.inl,*.c,*.m,*.mm,*.M",
     "*.h,*.hxx,*.hpp,*.hh,*.h++,*.H,*.tlh,*.idl",
     "*.adb",
+    "*.cs",
     "*.f",
     "*.html,*.htm",
     "*.hs",
@@ -71,7 +74,8 @@ const char *filepatterns[] = {
     "*.pl",
     "*.pp,*.pas",
     "*.py",
-    "*.rb",
+    "*.rb,*.rhtml,*.rjs,*.rxml",
+    "CMakeLists.txt,*.cmake",
     "*",
     0
 };
@@ -150,6 +154,11 @@ GrepDialog::GrepDialog( GrepViewPart * part, QWidget *parent, const char *name )
     QBoxLayout *dir_checks_layout = new QHBoxLayout(4);
     layout->addLayout(dir_checks_layout, 4, 1);
 	
+    regexp_box = new QCheckBox(i18n("Regular &Expression"), this);
+    regexp_box->setChecked(true);
+    dir_checks_layout->addSpacing(10);
+    dir_checks_layout->addWidget(regexp_box);
+
     recursive_box = new QCheckBox(i18n("&Recursive"), this);
     recursive_box->setChecked(config->readBoolEntry("recursive", true));
     dir_checks_layout->addSpacing(10);
