@@ -23,6 +23,16 @@ CompileErrorFilter::ErrorFormat::ErrorFormat( const char * regExp, int file, int
 {
 }
 
+CompileErrorFilter::ErrorFormat::ErrorFormat( const char * regExp, int file, int line, int text, QString comp )
+	: expression( regExp )
+	, fileGroup( file )
+	, lineGroup( line )
+	, textGroup( text )
+	, compiler( comp )
+{
+}
+
+
 CompileErrorFilter::CompileErrorFilter( OutputFilter& next )
 	: OutputFilter( next )
 {
@@ -36,12 +46,20 @@ CompileErrorFilter::ErrorFormat* CompileErrorFilter::errorFormats()
 		ErrorFormat( "([^: \t]+):([0-9]+):(?:[0-9]+):([^0-9]+)", 1, 2, 3 ),
 		// GCC
 		ErrorFormat( "([^: \t]+):([0-9]+):([^0-9]+)", 1, 2, 3 ),
+		// ICC
+		ErrorFormat( "([^: \\t]+)\\(([0-9]+)\\):([^0-9]+)", 1, 2, 3, "intel" ),
 		//libtool link
 		ErrorFormat( "(libtool):( link):( warning): ", 0, 0, 0 ),
 		// Fortran
 		ErrorFormat( "\"(.*)\", line ([0-9]+):(.*)", 1, 2, 3 ),
 		// Jade
 		ErrorFormat( "[a-zA-Z]+:([^: \t]+):([0-9]+):[0-9]+:[a-zA-Z]:(.*)", 1, 2, 3 ),
+		// ifort
+		ErrorFormat( "fortcom: Error: (.*), line ([0-9]+):(.*)", 1, 2, 3, "intel" ),
+		// PGI
+		ErrorFormat( "PGF9(.*)-(.*)-(.*)-(.*) \\((.*): ([0-9]+)\\)", 5, 6, 4, "pgi" ),
+		// PGI (2)
+		ErrorFormat( "PGF9(.*)-(.*)-(.*)-Symbol, (.*) \\((.*)\\)", 5, 5, 4, "pgi" ),
 
 		ErrorFormat( 0, 0, 0, 0 ) // this one last
 	};
@@ -55,19 +73,21 @@ void CompileErrorFilter::processLine( const QString& line )
 	QString file;
 	int lineNum = 0;
 	QString text;
+	QString compiler;
 	int i = 0;
 	bool isWarning = false;
-	ErrorFormat* errFormats = errorFormats();
+	ErrorFormat* const errFormats = errorFormats();
 	ErrorFormat* format = &errFormats[i];
 	while( !format->expression.isEmpty() )
 	{
-		QRegExp regExp = format->expression;
+		QRegExp& regExp = format->expression;
 
 		if ( regExp.search( line ) != -1 ) {
 	                hasmatch = true;
         	        file    = regExp.cap( format->fileGroup );
 	                lineNum = regExp.cap( format->lineGroup ).toInt() - 1;
 	                text    = regExp.cap( format->textGroup );
+			compiler = format->compiler;
 			if (regExp.cap(3).contains("warning", false))
 				isWarning = true;
 			break;
@@ -86,7 +106,7 @@ void CompileErrorFilter::processLine( const QString& line )
 
 	if ( hasmatch )
 	{
-		emit item( new ErrorItem( file, lineNum, text, line, isWarning ) );
+		emit item( new ErrorItem( file, lineNum, text, line, isWarning, compiler ) );
 	}
 	else
 	{
