@@ -3,6 +3,7 @@
 #include <qregexp.h>
 #include <qwidgetstack.h>
 
+#include <kprocess.h>
 #include <klocale.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
@@ -91,7 +92,10 @@ static const QString childrenParam( "--trace-children=yes" );
 
 QString ValgrindDialog::valParams() const
 {
-  QString params = w->valParamEdit->text();
+  QString params;
+  if (isNewValgrindVersion())
+    params = QString::fromLatin1( "--tool=memcheck " );
+  params += w->valParamEdit->text();
   if ( w->memleakBox->isChecked() )
     params += " " + leakCheckParam;
   if ( w->reachableBox->isChecked() )
@@ -183,3 +187,16 @@ void ValgrindDialog::setKcExecutable( const QString& ke )
   }
 }
 
+bool ValgrindDialog::isNewValgrindVersion( ) const
+{
+  KProcess *proc = new KProcess;
+  proc->setUseShell(true);
+  *proc << "test \"valgrind-20\" == `valgrind --version | awk -F \\. '{print $1$2}'`";
+  proc->start(KProcess::Block);
+  if (proc->normalExit())
+    return proc->exitStatus();
+  return true;
+}
+
+// kate: space-indent on; indent-width 2; tab-width 2; show-tabs on;
+
