@@ -1,10 +1,3 @@
-// Ewww... need this to access KParts::Part::setWidget(), so that kdevelop
-// doesn't need to be rearchitected for multiple views before the lazy view
-// creation can go in
-#define protected public
-#include <kparts/part.h>
-#undef protected
-
 #include <qwidget.h>
 #include <qpopupmenu.h>
 #include <qtimer.h>
@@ -15,6 +8,8 @@
 #include <kapplication.h>
 #include <kmdidefines.h>
 
+#include <kparts/part.h>
+
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 #include <ktexteditor/viewcursorinterface.h>
@@ -32,13 +27,11 @@
 #include "toplevel.h"
 #include "partcontroller.h"
 #include "core.h"
-#include "debugger.h"
 #include "newmainwindow.h"
-
+#include "multibuffer.h"
 
 #include "editorproxy.h"
 
-
 using namespace KTextEditor;
 
 EditorProxy *EditorProxy::s_instance = 0;
@@ -50,14 +43,14 @@ EditorProxy::EditorProxy()
 	KConfig *config = kapp->config();
 	config->setGroup("UI");
 	int mdimode = config->readNumEntry("MDIMode", KMdi::IDEAlMode);
-	
+
 	m_delayedViewCreationCompatibleUI = (mdimode == KMdi::IDEAlMode || mdimode == KMdi::TabPageMode);
 
-	KAction *ac = new KAction( i18n("Show Context Menu"), 0, this, 
+	KAction *ac = new KAction( i18n("Show Context Menu"), 0, this,
 		SLOT(showPopup()), TopLevel::getInstance()->main()->actionCollection(), "show_popup" );
-        KShortcut cut ;/*= KStdAccel::shortcut(KStdAccel::PopupMenuContext);*/
-        cut.append(KKey(CTRL+Key_Return));
-        ac->setShortcut(cut);
+    KShortcut cut ;/*= KStdAccel::shortcut(KStdAccel::PopupMenuContext);*/
+    cut.append(KKey(CTRL+Key_Return));
+    ac->setShortcut(cut);
 }
 
 
@@ -78,15 +71,16 @@ void EditorProxy::setLineNumber(KParts::Part *part, int lineNum, int col)
   if ( lineNum < 0 )
     return;
 
+  KURL url = dynamic_cast<KParts::ReadOnlyPart*>( part )->url();
+
   ViewCursorInterface *iface = dynamic_cast<ViewCursorInterface*>(part->widget());
   if (iface)
     iface->setCursorPositionReal(lineNum, col == -1 ? 0 : col);
   else {
     // Save the position for a rainy day (or when the view gets activated and wants its position)
-    for (QValueList<EditorWrapper*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
-      if ((*it)->document() == part) {
-        (*it)->setLine(lineNum);
-        (*it)->setCol(col);
+    for (QValueList<MultiBuffer*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
+        if ((*it)->hasURL( url )) {
+            (*it)->registerDelayedActivation( part, lineNum, col );
         return;
       }
 
@@ -115,7 +109,9 @@ void EditorProxy::installPopup( KParts::Part * part )
 
 			KAction * action = NULL;
 			//If there is a tab for this file, we don't need to plug the closing menu entries here
-			switch (dynamic_cast<NewMainWindow*>(TopLevel::getInstance())->getTabWidgetVisibility())
+			NewMainWindow *mw = dynamic_cast<NewMainWindow*>(TopLevel::getInstance());
+			if (mw) {
+			switch (mw->getTabWidgetVisibility())
 			{
 			case KMdi::AlwaysShowTabs:
 				break;
@@ -138,7 +134,24 @@ void EditorProxy::installPopup( KParts::Part * part )
 			default:
 				break;
 			}
-
+			}
+			else {
+				KConfig *config = KGlobal::config();
+				config->setGroup("UI");
+				bool m_tabBarShown = ! config->readNumEntry("TabWidgetVisibility", 0);
+				if (!m_tabBarShown)
+				{
+					action = TopLevel::getInstance()->main()->actionCollection()->action( "file_close" );
+					if ( action && !action->isPlugged( popup ) )
+					{
+						popup->insertSeparator( 0 );
+						action->plug( popup, 0 );
+					}
+					action = TopLevel::getInstance()->main()->actionCollection()->action( "file_closeother" );
+					if ( action && !action->isPlugged( popup ) )
+						action->plug( popup, 1 );
+				}
+			}
 
 			iface->installPopup( popup );
 
@@ -202,7 +215,7 @@ void EditorProxy::popupAboutToShow()
   if( selectIface && selectIface->hasSelection() )
   {
     hasMultilineSelection = ( selectIface->selection().contains('\n') != 0 );
-    if ( !hasMultilineSelection ) 
+    if ( !hasMultilineSelection )
     {
       wordstr = selectIface->selection();
     }
@@ -252,129 +265,56 @@ void EditorProxy::showPopup( )
 
 	if ( KParts::Part * part = PartController::getInstance()->activePart() )
 	{
-		ViewCursorInterface *iface = dynamic_cast<ViewCursorInterface*>( part->widget() );	
+		ViewCursorInterface *iface = dynamic_cast<ViewCursorInterface*>( part->widget() );
 		if ( iface )
 		{
 			KTextEditor::View * view = static_cast<KTextEditor::View*>( part->widget() );
 			QPopupMenu * popup = static_cast<QPopupMenu*>( view->factory()->container("ktexteditor_popup", view ) );
-			
+
 			popup->exec( view->mapToGlobal( iface->cursorCoordinates() ) );
 		}
 	}
-  	
 }
 
-void EditorProxy::registerEditor(EditorWrapper* wrapper)
+void EditorProxy::registerEditor(MultiBuffer* wrapper)
 {
   m_editorParts.append(wrapper);
 }
 
-void EditorProxy::deregisterEditor(EditorWrapper* wrapper)
+void EditorProxy::deregisterEditor(MultiBuffer* wrapper)
 {
   m_editorParts.remove(wrapper);
 }
 
-EditorWrapper::EditorWrapper(KTextEditor::Document* editor, bool activate, QWidget* parent, const char* name)
-  : QWidgetStack(parent, name)
-  , m_doc(editor)
-  , m_view(0L)
-  , m_line(0)
-  , m_col(0)
-  , m_first(!activate && EditorProxy::getInstance()->isDelayedViewCapable())
-{
-  EditorProxy::getInstance()->registerEditor(this);
-}
-
-EditorWrapper::~EditorWrapper()
-{
-  kdDebug() << k_funcinfo << this << endl;
-  EditorProxy::getInstance()->deregisterEditor(this);
-}
-
-KTextEditor::Document* EditorWrapper::document() const
-{
-  return m_doc;
-}
-
-void EditorWrapper::setLine(int line)
-{
-  m_line = line;
-}
-
-void EditorWrapper::setCol(int col)
-{
-  m_col = col;
-}
-
-void EditorWrapper::show()
-{
-  if ( !m_doc ) {
-    QWidgetStack::show();
-    return;
-  }
-  
-  if (m_first) {
-    m_first = false;
-    QWidgetStack::show();
-    return;
-  }
-
-  if (m_doc->widget()) {
-    QWidgetStack::show();
-    return;
-  }
-
-  m_view = m_doc->createView(this);
-  
-  addWidget(m_view);
-  
-  m_doc->setWidget(m_view);
-  // FIXME assumption check
-  // We're managing the view deletion by being its parent, don't let the part self-destruct
-  disconnect( m_view, SIGNAL( destroyed() ), m_doc, SLOT( slotWidgetDestroyed() ) );
-  //connect( m_view, SIGNAL( destroyed() ), this, SLOT( deleteLater() ) );
-  
-  m_doc->insertChildClient(m_view);
-
-  PartController::getInstance()->integrateTextEditorPart(m_doc);
-
-  ViewCursorInterface *iface = dynamic_cast<ViewCursorInterface*>(static_cast<KTextEditor::View*>(m_view));
-  if (iface) {
-    iface->setCursorPositionReal(m_line, m_col == -1 ? 0 : m_col);
-
-  } else {
-    // Shouldn't get here
-    Q_ASSERT(false);
-  }
-
-  QWidgetStack::show();
-}
-
 QWidget * EditorProxy::widgetForPart( KParts::Part * part )
 {
 	if ( !part ) return 0;
-	
+
 	if (part->widget())
 		return part->widget();
-	
-	for (QValueList<EditorWrapper*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
-		if ((*it)->document() == part)
+    
+    KURL url = dynamic_cast<KParts::ReadOnlyPart*>( part )->url();
+    
+    for (QValueList<MultiBuffer*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
+        if ((*it)->hasURL( url ))
 			return *it;
-	
+
 	return 0L;
 }
 
 QWidget * EditorProxy::topWidgetForPart( KParts::Part * part )
 {
 	if ( !part ) return 0;
-	
-	for (QValueList<EditorWrapper*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
-		if ((*it)->document() == part)
+    
+    KURL url = dynamic_cast<KParts::ReadOnlyPart*>( part )->url();
+    
+    for (QValueList<MultiBuffer*>::ConstIterator it = m_editorParts.begin(); it != m_editorParts.end(); ++it)
+        if ((*it)->hasURL( url ))
 			return *it;
-	
+
 	if (part->widget())
 		return part->widget();
-	
+
 	return 0L;
 }
 
