@@ -7,44 +7,13 @@
 #include <qguardedptr.h>
 
 class QPopupMenu;
+class MultiBuffer;
 
 #include <kparts/part.h>
 #include <ktexteditor/markinterface.h>
 #include <kdeversion.h>
 # include <ktexteditor/markinterfaceextension.h>
 
-#include <qwidgetstack.h>
-
-/**
-Editor proxy for delayed loading of editor parts.
-*/
-class EditorWrapper : public QWidgetStack
-{
-  Q_OBJECT
-
-public:
-  EditorWrapper(KTextEditor::Document* editor, bool activate, QWidget* parent, const char* name = 0L);
-  virtual ~EditorWrapper();
-
-  KTextEditor::Document* document() const;
-
-  void setLine(int line);
-  void setCol(int col);
-
-public slots:
-  virtual void show();
-
-protected:
-  virtual void focusInEvent(QFocusEvent *ev);
-  
-private:
-  QGuardedPtr<KTextEditor::Document> m_doc;
-  QGuardedPtr<KTextEditor::View> m_view;
-  int m_line;
-  int m_col;
-  bool m_first;
-};
-
 class EditorProxy : public QObject
 {
   Q_OBJECT
@@ -57,8 +26,8 @@ public:
 
   void installPopup(KParts::Part *part);
   
-  void registerEditor(EditorWrapper* wrapper);
-  void deregisterEditor(EditorWrapper* wrapper);
+  void registerEditor(MultiBuffer* wrapper);
+  void deregisterEditor(MultiBuffer* wrapper);
 
   QWidget * widgetForPart( KParts::Part * part );
   QWidget * topWidgetForPart( KParts::Part * part );
@@ -79,7 +48,7 @@ private:
   QMemArray<int> m_popupIds;
 
   // This list is used to save line/col information for not yet activated editor views.
-  QValueList< EditorWrapper* > m_editorParts;
+  QValueList< MultiBuffer* > m_editorParts;
   
   bool m_delayedViewCreationCompatibleUI;
 };
