@@ -66,13 +66,20 @@ void KDevIDEExtension::createGlobalSettingsPage(KDialogBase *dlg)
     gsw->lineWrappingCheckBox->setChecked(config->readBoolEntry("LineWrapping",true));
     gsw->dirNavigMsgCheckBox->setChecked(config->readBoolEntry("ShowDirNavigMsg",false));
     gsw->compileOutputCombo->setCurrentItem(config->readNumEntry("CompilerOutputLevel",2));
+
     config->setGroup("General Options");
     gsw->projectsURL->setURL(config->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/"));
     gsw->designerButtonGroup->setButton( config->readNumEntry( "DesignerApp", 0 ) );
 
+    QString DesignerSetting = config->readEntry( "DesignerSetting", "ExternalDesigner" );
+    gsw->qtDesignerRadioButton->setChecked( DesignerSetting == "ExternalDesigner" );
+    gsw->seperateAppRadioButton->setChecked( DesignerSetting == "ExternalKDevDesigner" );
+    gsw->embeddedDesignerRadioButton->setChecked( DesignerSetting == "EmbeddedKDevDesigner" );
+
     config->setGroup("TerminalEmulator");
     gsw->terminalButtonGroup->setButton( config->readNumEntry( "UseKDESetting", 0 ) );
     gsw->terminalEdit->setText( config->readEntry( "TerminalApplication", QString::fromLatin1("konsole") ) );
+
 }
 
 void KDevIDEExtension::acceptGlobalSettingsPage(KDialogBase *dlg)
@@ -84,6 +91,13 @@ void KDevIDEExtension::acceptGlobalSettingsPage(KDialogBase *dlg)
     config->writeEntry("Read Last Project On Startup",gsw->lastProjectCheckbox->isChecked());
     config->writePathEntry("DefaultProjectsDir", gsw->projectsURL->url());
     config->writeEntry("OutputViewFont", gsw->outputFont->font());
+
+    QString DesignerSetting;
+    if ( gsw->qtDesignerRadioButton->isChecked() ) DesignerSetting = "ExternalDesigner";
+    if ( gsw->seperateAppRadioButton->isChecked() ) DesignerSetting = "ExternalKDevDesigner";
+    if ( gsw->embeddedDesignerRadioButton->isChecked() ) DesignerSetting = "EmbeddedKDevDesigner";
+    config->writeEntry( "DesignerSetting", DesignerSetting );
+
     config->setGroup("MakeOutputView");
     config->writeEntry("LineWrapping",gsw->lineWrappingCheckBox->isChecked());
     config->writeEntry("ShowDirNavigMsg",gsw->dirNavigMsgCheckBox->isChecked());
