@@ -57,6 +57,10 @@ SimpleMainWindow::SimpleMainWindow(QWidget* parent, const char *name)
 {
     resize(800, 600); // starts kdevelop at 800x600 the first time
     m_mainWindowShare = new MainWindowShare(this);
+
+    connect(m_bottomDock, SIGNAL(hidden()), this, SLOT(raiseEditor()));
+    connect(m_leftDock, SIGNAL(hidden()), this, SLOT(raiseEditor()));
+    connect(m_rightDock, SIGNAL(hidden()), this, SLOT(raiseEditor()));
 }
 
 SimpleMainWindow::~ SimpleMainWindow( )
@@ -69,26 +73,26 @@ void SimpleMainWindow::init()
     actionCollection()->setHighlightingEnabled( true );
     setStandardToolBarMenuEnabled( true );
     setXMLFile(ShellExtension::getInstance()->xmlFile());
-    
+
     createFramework();
     createActions();
     new KDevStatusBar(this);
 
     createGUI(0);
-    
+
     m_mainWindowShare->init();
     setupWindowMenu();
     menuBar()->setEnabled( false );
 
     //FIXME: this checks only for global offers which is not quite correct because
     //a profile can offer core plugins and no global plugins.
-    if ( PluginController::getInstance()->engine().allOffers(ProfileEngine::Global).isEmpty() ) 
+    if ( PluginController::getInstance()->engine().allOffers(ProfileEngine::Global).isEmpty() )
     {
         KMessageBox::sorry( this, i18n("Unable to find plugins, KDevelop will not work"
             " properly.\nPlease make sure "
             "that KDevelop is installed in your KDE directory; otherwise, you have "
             "to add KDevelop's installation "
-            "path to the environment variable KDEDIRS and run kbuildsycoca. Restart " 
+            "path to the environment variable KDEDIRS and run kbuildsycoca. Restart "
             "KDevelop afterwards.\n"
             "Example for BASH users:\nexport KDEDIRS=/path/to/kdevelop:$KDEDIRS && kbuildsycoca"),
             i18n("Could Not Find Plugins") );
@@ -96,18 +100,67 @@ void SimpleMainWindow::init()
 
     connect(Core::getInstance(), SIGNAL(coreInitialized()), this, SLOT(slotCoreInitialized()));
     connect(Core::getInstance(), SIGNAL(projectOpened()), this, SLOT(projectOpened()));
+    connect(Core::getInstance(), SIGNAL(contextMenu(QPopupMenu *, const Context *)),
+        this, SLOT(contextMenu(QPopupMenu *, const Context *)));
     connect(PartController::getInstance(), SIGNAL(partURLChanged(KParts::ReadOnlyPart *)),
         this, SLOT(slotPartURLChanged(KParts::ReadOnlyPart * )));
     connect(PartController::getInstance(), SIGNAL(activePartChanged(KParts::Part*)),
         this, SLOT(activePartChanged(KParts::Part*)));
 
-    connect(PartController::getInstance(), 
+    connect(PartController::getInstance(),
         SIGNAL(documentChangedState(const KURL &, DocumentState)),
         this, SLOT(documentChangedState(const KURL&, DocumentState)));
 
     loadSettings();
 }
 
+void SimpleMainWindow::contextMenu(QPopupMenu *popupMenu, const Context *context)
+{
+    int cont = context->type();
+    m_splitURLs.clear();
+    if (cont == Context::EditorContext)
+    {
+        KURL url = static_cast<const EditorContext*>(context)->url();
+        QWidget *w = widgetForURL(url);
+        if (w && m_widgetTabs[w] && m_widgetTabs[w]->count() > 1)
+        {
+            m_splitURLs.append(url);
+            m_splitHor1->plug(popupMenu);
+            m_splitVer1->plug(popupMenu);
+            popupMenu->insertSeparator();
+        }
+    }
+    else if (cont == Context::FileContext)
+    {
+        if (PartController::getInstance()->openURLs().count() > 0)
+        {
+            m_splitURLs = static_cast<const FileContext*>(context)->urls();
+            bool isOpen = true;
+            for (KURL::List::const_iterator it = m_splitURLs.begin(); it != m_splitURLs.end(); ++it)
+            {
+                if (!PartController::getInstance()->openURLs().contains(*it))
+                {
+                    isOpen = false;
+                    break;
+                }
+            }
+            if (isOpen && PartController::getInstance()->openURLs().count() == 1)
+                return;
+            popupMenu->insertSeparator();
+            if (isOpen)
+            {
+                m_splitHor1->plug(popupMenu);
+                m_splitVer1->plug(popupMenu);
+            }
+            else
+            {
+                m_splitHor2->plug(popupMenu);
+                m_splitVer2->plug(popupMenu);
+            }
+        }
+    }
+}
+
 void SimpleMainWindow::embedPartView(QWidget *view, const QString &title, const QString &/*toolTip*/)
 {
     kdDebug() << "SimpleMainWindow::embedPartView: " << view << endl;
@@ -169,13 +222,15 @@ void SimpleMainWindow::raiseView(QWidget *view)
     //editor view is passed to this function but the ui library knows only
     //of its parent which is an editor wrapper, simply replacing the view
     //by its wrapper helps here
-    if (view->parent() && view->parent()->isA("EditorWrapper"))
+    if (view->parent())
+        kdDebug() << view->parent()->className() << endl;
+    if (view->parent() && (view->parent()->isA("EditorWrapper") || view->parent()->isA("MultiBuffer")))
     {
-//         kdDebug() << "parent is editor wrapper: " << 
+//         kdDebug() << "parent is editor wrapper: " <<
 //             static_cast<EditorWrapper*>(view->parent()) << endl;
         view = (QWidget*)view->parent();
     }
-    
+
     if (m_docks.contains(view))
     {
         DDockWindow *dock = toolWindow(m_docks[view]);
@@ -204,8 +259,13 @@ void SimpleMainWindow::saveSettings( )
 
     ProjectManager::getInstance()->saveSettings();
     saveMainWindowSettings(config, "SimpleMainWindow");
+
+    DMainWindow::saveSettings();
 }
 
+void SimpleMainWindow::setCurrentDocumentCaption( const QString &caption )
+{}
+
 KMainWindow *SimpleMainWindow::main()
 {
     return this;
@@ -215,7 +275,7 @@ void SimpleMainWindow::createFramework()
 {
     PartController::createInstance( this );
 
-    connect(PartController::getInstance(), SIGNAL(activePartChanged(KParts::Part*)), 
+    connect(PartController::getInstance(), SIGNAL(activePartChanged(KParts::Part*)),
         this, SLOT(createGUI(KParts::Part*)));
 }
 
@@ -225,16 +285,37 @@ void SimpleMainWindow::createActions()
         this, SLOT(raiseEditor()), actionCollection(), "raise_editor");
     m_raiseEditor->setToolTip(i18n("Raise editor"));
     m_raiseEditor->setWhatsThis(i18n("<b>Raise editor</b><p>Focuses the editor."));
-    
-    new KAction(i18n("Split &Horizontal"), CTRL+SHIFT+Key_T,
-        this, SLOT(slotSplitHorizontal()), actionCollection(), "split_h");
 
-    new KAction(i18n("Split &Vertical"), CTRL+SHIFT+Key_L,
-        this, SLOT(slotSplitVertical()), actionCollection(), "split_v");
-    
-    KStdAction::configureToolbars(this, SLOT(configureToolbars()), 
+    m_splitHor = new KAction(i18n("Split &Horizontal"), CTRL+SHIFT+Key_T,
+        this, SLOT(slotSplitHorizontalBase()), actionCollection(), "split_h");
+
+    m_splitVer = new KAction(i18n("Split &Vertical"), CTRL+SHIFT+Key_L,
+        this, SLOT(slotSplitVerticalBase()), actionCollection(), "split_v");
+
+    m_splitHor1 = new KAction(i18n("Split &Horizontal"), 0,
+        this, SLOT(slotSplitHorizontal()), actionCollection(), "split_h1");
+
+    m_splitVer1 = new KAction(i18n("Split &Vertical"), 0,
+        this, SLOT(slotSplitVertical()), actionCollection(), "split_v1");
+
+    m_splitHor2 = new KAction(i18n("Split &Horizontal and Open"), 0,
+        this, SLOT(slotSplitHorizontal()), actionCollection(), "split_h2");
+
+    m_splitVer2 = new KAction(i18n("Split &Vertical and Open"), 0,
+        this, SLOT(slotSplitVertical()), actionCollection(), "split_v2");
+
+    m_raiseLeftDock = new KAction(i18n("Switch Left Dock"), CTRL+SHIFT+ALT+Key_L,
+        this, SLOT(raiseLeftDock()), actionCollection(), "switch_left_dock");
+
+    m_raiseRightDock = new KAction(i18n("Switch Right Dock"), CTRL+SHIFT+ALT+Key_R,
+        this, SLOT(raiseRightDock()), actionCollection(), "switch_right_dock");
+
+    m_raiseBottomDock = new KAction(i18n("Switch Bottom Dock"), CTRL+SHIFT+ALT+Key_B,
+        this, SLOT(raiseBottomDock()), actionCollection(), "switch_bottom_dock");
+
+    KStdAction::configureToolbars(this, SLOT(configureToolbars()),
         actionCollection(), "set_configure_toolbars");
-    
+
     m_mainWindowShare->createActions();
 
     connect(m_mainWindowShare, SIGNAL(gotoNextWindow()), this, SLOT(gotoNextWindow()));
@@ -245,6 +326,7 @@ void SimpleMainWindow::createActions()
 
 void SimpleMainWindow::raiseEditor()
 {
+    kdDebug() << "SimpleMainWindow::raiseEditor" << endl;
     KDevPartController *partcontroller = API::getInstance()->partController();
     if (partcontroller->activePart() && partcontroller->activePart()->widget())
         partcontroller->activePart()->widget()->setFocus();
@@ -252,18 +334,36 @@ void SimpleMainWindow::raiseEditor()
 
 void SimpleMainWindow::gotoNextWindow()
 {
-    if ((m_activeTabWidget->currentPageIndex() + 1) < m_activeTabWidget->count())
-        m_activeTabWidget->setCurrentPage(m_activeTabWidget->currentPageIndex() + 1);
+    if (m_bottomDock->isActive())
+        m_bottomDock->selectNextWidget();
+    else if (m_rightDock->isActive())
+        m_rightDock->selectNextWidget();
+    else if (m_leftDock->isActive())
+        m_leftDock->selectNextWidget();
     else
-        m_activeTabWidget->setCurrentPage(0);
+    {
+        if ((m_activeTabWidget->currentPageIndex() + 1) < m_activeTabWidget->count())
+            m_activeTabWidget->setCurrentPage(m_activeTabWidget->currentPageIndex() + 1);
+        else
+            m_activeTabWidget->setCurrentPage(0);
+    }
 }
 
 void SimpleMainWindow::gotoPreviousWindow()
 {
-    if ((m_activeTabWidget->currentPageIndex() - 1) >= 0)
-        m_activeTabWidget->setCurrentPage(m_activeTabWidget->currentPageIndex() - 1);
+    if (m_bottomDock->isActive())
+        m_bottomDock->selectPrevWidget();
+    else if (m_rightDock->isActive())
+        m_rightDock->selectPrevWidget();
+    else if (m_leftDock->isActive())
+        m_leftDock->selectPrevWidget();
     else
-        m_activeTabWidget->setCurrentPage(m_activeTabWidget->count() - 1);
+    {
+        if ((m_activeTabWidget->currentPageIndex() - 1) >= 0)
+            m_activeTabWidget->setCurrentPage(m_activeTabWidget->currentPageIndex() - 1);
+        else
+            m_activeTabWidget->setCurrentPage(m_activeTabWidget->count() - 1);
+    }
 }
 
 void SimpleMainWindow::gotoFirstWindow()
@@ -278,7 +378,7 @@ void SimpleMainWindow::gotoLastWindow()
 
 void SimpleMainWindow::slotCoreInitialized()
 {
-    menuBar()->setEnabled(true);    
+    menuBar()->setEnabled(true);
 }
 
 void SimpleMainWindow::projectOpened()
@@ -333,7 +433,13 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
 
 void SimpleMainWindow::closeTab()
 {
-    actionCollection()->action("file_close")->activate();
+//    actionCollection()->action("file_close")->activate();
+    if (sender()->isA("QToolButton") && sender()->parent()->isA("DTabWidget"))
+    {
+        DTabWidget *tab = (DTabWidget*)sender()->parent();
+        if (tab && tab->currentPage())
+            closeTab(tab->currentPage());
+    }
 }
 
 void SimpleMainWindow::tabContext(QWidget *w, const QPoint &p)
@@ -341,7 +447,7 @@ void SimpleMainWindow::tabContext(QWidget *w, const QPoint &p)
     DTabWidget *tabWidget = static_cast<DTabWidget*>(const_cast<QObject*>(sender()));
     if (!tabWidget)
         return;
-    
+
     KPopupMenu tabMenu;
     tabMenu.insertTitle(tabWidget->tabLabel(w));
 
@@ -507,7 +613,7 @@ void SimpleMainWindow::fillWindowMenu()
 
     if (list.count() > 0)
         m_windowList << qMakePair(m_windowMenu->insertSeparator(), KURL());
-    
+
     while (itt != list.end())
     {
         temp = m_windowMenu->insertItem( i < 10 ? QString("&%1 %2").arg(i).arg((*itt).fileName()) : (*itt).fileName() );
@@ -520,27 +626,87 @@ void SimpleMainWindow::fillWindowMenu()
 void SimpleMainWindow::slotSplitVertical()
 {
     DTabWidget *tab = splitVertical();
-    PartController::getInstance()->openEmptyTextDocument();
-    
-    //FIXME: adymo: we can't put another kate view into the tab just added - weird crashes :(
-    //more: kdevelop part controller doesn't handle such situation - it assumes the part to
-    //have only one widget
-/*    KParts::Part *activePart = PartController::getInstance()->activePart();
-    if (!activePart)
-        return;
-    KTextEditor::Document *activeDoc = dynamic_cast<KTextEditor::Document *>(activePart);
-    if (!activeDoc)
-        return;
-
-    QWidget *view = activeDoc->createView(0);
-    addWidget(tab, view, "");
-    view->show();*/
+    openDocumentsAfterSplit(tab);
 }
 
 void SimpleMainWindow::slotSplitHorizontal()
 {
     DTabWidget *tab = splitHorizontal();
-    PartController::getInstance()->openEmptyTextDocument();
+    openDocumentsAfterSplit(tab);
+}
+
+void SimpleMainWindow::slotSplitVerticalBase()
+{
+    if (KParts::ReadOnlyPart *ro_part = activePartForSplitting())
+    {
+        m_splitURLs << ro_part->url();
+        slotSplitVertical();
+    }
+}
+
+KParts::ReadOnlyPart *SimpleMainWindow::activePartForSplitting()
+{
+    if (PartController::getInstance()->openURLs().count() < 2)
+        return 0;
+    m_splitURLs.clear();
+    KParts::ReadOnlyPart *ro_part =
+        dynamic_cast<KParts::ReadOnlyPart*>(PartController::getInstance()->activePart());
+    return ro_part;
+}
+
+void SimpleMainWindow::slotSplitHorizontalBase()
+{
+    if (KParts::ReadOnlyPart *ro_part = activePartForSplitting())
+    {
+        m_splitURLs << ro_part->url();
+        slotSplitHorizontal();
+    }
+}
+
+void SimpleMainWindow::openDocumentsAfterSplit(DTabWidget *tab)
+{
+    if (m_splitURLs.count() > 0)
+    {
+        for (KURL::List::const_iterator it = m_splitURLs.begin(); it != m_splitURLs.end(); ++it)
+        {
+            KParts::ReadOnlyPart *part = PartController::getInstance()->partForURL(*it);
+            if (!part)
+                PartController::getInstance()->editDocument(*it);
+            else
+            {
+                QWidget *inTab = widgetForURL(*it);
+                if (inTab)
+                {
+                    DTabWidget *oldTab = m_widgetTabs[inTab];
+                    QString title = oldTab->tabLabel(inTab);
+                    removeWidget(inTab);
+                    addWidget(tab, inTab, title);
+                }
+            }
+        }
+        m_splitURLs.clear();
+    }
+}
+
+QWidget *SimpleMainWindow::widgetForURL(KURL url)
+{
+    KParts::ReadOnlyPart *part = PartController::getInstance()->partForURL(url);
+    return widgetInTab(part->widget());
+}
+
+QWidget *SimpleMainWindow::widgetInTab(QWidget *w)
+{
+    QWidget *inTab = 0;
+    if (w && w->parent() && w->parent()->isA("EditorProxy"))
+        inTab = (QWidget*)w->parent();
+    else if (w && w->parent() && w->parent()->isA("MultiBuffer")
+        && w->parent()->parent() && w->parent()->parent()->isA("EditorProxy"))
+        inTab = (QWidget*)w->parent()->parent();
+    else if (w && w->parent() && w->parent()->isA("MultiBuffer"))
+        inTab = (QWidget*)w->parent();
+    else
+        inTab = w;
+    return inTab;
 }
 
 void SimpleMainWindow::closeTab(QWidget *w)
@@ -565,13 +731,40 @@ void SimpleMainWindow::activePartChanged(KParts::Part *part)
         return;
     QWidget *w = part->widget();
     kdDebug() << "active part widget is : " << w << endl;
-    if (!m_widgets.contains(w))
-        return;
-    if (m_widgetTabs[w] != 0)
+    QWidget *inTab = widgetInTab(w);
+    if (m_widgetTabs[inTab] != 0)
     {
         kdDebug() << " setting m_activeTabWidget " << endl;
-        m_activeTabWidget = m_widgetTabs[w];
+        m_activeTabWidget = m_widgetTabs[inTab];
     }
 }
 
+void SimpleMainWindow::createGUI(KParts::Part *part) {
+    if ( !part )
+        setCaption( QString::null );
+    DMainWindow::createGUI(part);
+
+    m_mainWindowShare->slotGUICreated( part );
+}
+
+void SimpleMainWindow::raiseBottomDock()
+{
+    raiseDock(m_bottomDock);
+}
+
+void SimpleMainWindow::raiseLeftDock()
+{
+    raiseDock(m_leftDock);
+}
+
+void SimpleMainWindow::raiseRightDock()
+{
+    raiseDock(m_rightDock);
+}
+
+void SimpleMainWindow::raiseDock(DDockWindow *dock)
+{
+    dock->selectLastWidget();
+}
+
 #include "simplemainwindow.moc"
