@@ -43,8 +43,8 @@ CVSLogPage::CVSLogPage( CvsService_stub *cvsService, QWidget *parent, const char
     thisLayout->add( m_textBrowser );
 
     /// \FIXME a better way?
-    m_textBrowser->setMinimumWidth(fontMetrics().maxWidth()*40);
-    m_textBrowser->setMinimumHeight(fontMetrics().maxWidth()*43);
+    m_textBrowser->setMinimumWidth(fontMetrics().width('X')*50);
+    m_textBrowser->setMinimumHeight(fontMetrics().width('X')*43);
 
     connect( m_textBrowser, SIGNAL(linkClicked( const QString& )), this, SLOT(slotLinkClicked( const QString& )) );
 }
@@ -68,6 +68,7 @@ void CVSLogPage::startLog( const QString &workDir, const QString &pathName )
 //    CvsOptions *options = CvsOptions::instance();
     // "cvs log" needs to be done on relative-path basis
     m_pathName = pathName;
+	m_diffStrings.clear();
 
     DCOPRef job = m_cvsService->log( pathName );
     m_cvsLogJob = new CvsJob_stub( job.app(), job.obj() );
@@ -75,7 +76,7 @@ void CVSLogPage::startLog( const QString &workDir, const QString &pathName )
     // establish connections to the signals of the cvs m_job
     connectDCOPSignal( job.app(), job.obj(), "jobExited(bool, int)", "slotJobExited(bool, int)", true );
     // We'll read the ouput directly from the job ...
-//    connectDCOPSignal( job.app(), job.obj(), "receivedStdout(QString)", "slotReceivedOutput(QString)", true );
+    connectDCOPSignal( job.app(), job.obj(), "receivedStdout(QString)", "slotReceivedOutput(QString)", true );
 //    connectDCOPSignal( job.app(), job.obj(), "receivedStderr(QString)", "slotReceivedErrors(QString)", true );
 
     kdDebug(9006) << "Running: " << m_cvsLogJob->cvsCommand() << endl;
@@ -123,9 +124,8 @@ void CVSLogPage::slotJobExited( bool normalExit, int exitStatus )
     static QRegExp rx_rev( "revision ((\\d+\\.?)+)" );
     m_textBrowser->setTextFormat( QTextBrowser::PlainText );
 
-    QStringList lines = m_cvsLogJob->output();
-    for (size_t i=0; i<lines.count(); ++i) {
-        QString s = lines[i];
+    for (size_t i=0; i<m_diffStrings.count(); ++i) {
+        QString s = m_diffStrings[i];
         kdDebug(9006) << "Examining line: " << s << endl;
         if ( rx_rev.exactMatch(s) )
         {
@@ -177,7 +177,7 @@ void CVSLogPage::slotLinkClicked( const QString &link )
     QString v2 = ver.section( '_', 1, 1 );
     if ( v1.isEmpty() || v2.isEmpty() )
     {
-        m_textBrowser->append( "invalid link clicked" );
+        m_textBrowser->append( i18n( "invalid link clicked" ) );
         return;
     }
 
@@ -191,6 +191,7 @@ void CVSLogPage::slotReceivedOutput( QString someOutput )
     kdDebug(9006) << "CVSLogPage::slotReceivedOutput(QString)" << endl;
 
     kdDebug(9006) << "OUTPUT: " << someOutput << endl;
+	m_diffStrings += m_outputBuffer.process(someOutput);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
